==> risk-center-api-0.4.0-20180726.092333-5-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskReviewHisDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;/**
 * Created by chengdeman .
 * 18/2/27 .
 */

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 风控审核记录表dto
 *
 * @author chengdeman
 * @create 2018-02-27 下午5:34
 **/
public class RiskReviewHisDto implements Serializable{


    private static final long serialVersionUID = 201998635393628729L;

    /**
     * 主键ID
     */
    private Long id;

    /**
     * 审核表主键
     */
    private Long  riskAllId;

    /**
     * 审核人
     */
    private String riskReviewer;

    /**
     * 审核结果
     */
    private Integer reviewResult;

    /**
     * 操作行为
     */
    private String reviewAction;

    /**
     * 审核时间
     */
    private String reviewTime;

    private Integer rate;

    private String mediaMemo;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRiskAllId() {
        return riskAllId;
    }

    public void setRiskAllId(Long riskAllId) {
        this.riskAllId = riskAllId;
    }

    public Integer getReviewResult() {
        return reviewResult;
    }

    public void setReviewResult(Integer reviewResult) {
        this.reviewResult = reviewResult;
    }

    public String getReviewAction() {
        return reviewAction;
    }

    public void setReviewAction(String reviewAction) {
        this.reviewAction = reviewAction;
    }

    public String getRiskReviewer() {
        return riskReviewer;
    }

    public void setRiskReviewer(String riskReviewer) {
        this.riskReviewer = riskReviewer;
    }

    public String getReviewTime() {
        return reviewTime;
    }

    public void setReviewTime(String reviewTime) {
        this.reviewTime = reviewTime;
    }

	public Integer getRate() {
		return rate;
	}

	public void setRate(Integer rate) {
		this.rate = rate;
	}

	public String getMediaMemo() {
		return mediaMemo;
	}

	public void setMediaMemo(String mediaMemo) {
		this.mediaMemo = mediaMemo;
	}

	@Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}

==> risk-center-api-0.5.90-20230612.025943-8-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskReviewHisDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;/**
 * Created by chengdeman .
 * 18/2/27 .
 */

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 风控审核记录表dto
 *
 * @author chengdeman
 * @create 2018-02-27 下午5:34
 **/
public class RiskReviewHisDto implements Serializable{


    private static final long serialVersionUID = 201998635393628729L;

    /**
     * 主键ID
     */
    private Long id;

    /**
     * 审核表主键
     */
    private Long  riskAllId;

    /**
     * 审核人
     */
    private String riskReviewer;

    /**
     * 审核结果
     */
    private Integer reviewResult;

    /**
     * 操作行为
     */
    private String reviewAction;

    /**
     * 审核时间
     */
    private String reviewTime;

    private Integer rate;

    private String mediaMemo;

    //原分成比例
    private Integer originRate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRiskAllId() {
        return riskAllId;
    }

    public void setRiskAllId(Long riskAllId) {
        this.riskAllId = riskAllId;
    }

    public Integer getReviewResult() {
        return reviewResult;
    }

    public void setReviewResult(Integer reviewResult) {
        this.reviewResult = reviewResult;
    }

    public String getReviewAction() {
        return reviewAction;
    }

    public void setReviewAction(String reviewAction) {
        this.reviewAction = reviewAction;
    }

    public String getRiskReviewer() {
        return riskReviewer;
    }

    public void setRiskReviewer(String riskReviewer) {
        this.riskReviewer = riskReviewer;
    }

    public String getReviewTime() {
        return reviewTime;
    }

    public void setReviewTime(String reviewTime) {
        this.reviewTime = reviewTime;
    }

	public Integer getRate() {
		return rate;
	}

	public void setRate(Integer rate) {
		this.rate = rate;
	}

	public String getMediaMemo() {
		return mediaMemo;
	}

	public void setMediaMemo(String mediaMemo) {
		this.mediaMemo = mediaMemo;
	}

    public Integer getOriginRate() {
        return originRate;
    }

    public void setOriginRate(Integer originRate) {
        this.originRate = originRate;
    }

    @Override
	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}
}
